---------------------------------------------------------------------------------
--
-- Prat - A framework for World of Warcraft chat mods
--
-- Copyright (C) 2006-2007  Prat Development Team
--
-- This program is free software; you can redistribute it and/or
-- modify it under the terms of the GNU General Public License
-- as published by the Free Software Foundation; either version 2
-- of the License, or (at your option) any later version.
--
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
--
-- You should have received a copy of the GNU General Public License
-- along with this program; if not, write to:
--
-- Free Software Foundation, Inc., 
-- 51 Franklin Street, Fifth Floor, 
-- Boston, MA  02110-1301, USA.
--
--
-------------------------------------------------------------------------------



--[[
Name: Prat_Presets
Revision: $Revision: 28458 $
-- !!
Your Name (sylvanaar@mindspring.com)
Author(s):  ( sylvanaar )
Website: http://files.wowace.com/Prat/
Documentation: http://www.wowace.com/wiki/Prat/Integrated_Modules#Presets
Subversion: http://svn.wowace.com/wowace/trunk/Prat/
Discussions: http://groups.google.com/group/wow-prat
Issues and feature requests: http://code.google.com/p/prat/issues/list
Description: Preset Prat configurations to help get you started (default=off).
Dependencies: Prat
]]

-- set prat module name
local PRAT_MODULE = Prat:RequestModuleName("PratPresets")

-- define localized strings
local L = AceLibrary("AceLocale-2.2"):new(PRAT_MODULE)

L:RegisterTranslations("enUS", function() return {
	["Presets"] = true,
	["Preset Prat configurations to help get you started"] = true,
	["AllOff_name"] = "All Modules Off",
	["AllOff_desc"] = "Turn everything off so you can just turn on what you want.",
	} end)

L:RegisterTranslations("deDE", function() return {
	["Presets"] = "Voreinstellungen",
	["Preset Prat configurations to help get you started"] = "Prat Konfigurations Voreinstellungen um dir zu helfen neu anzufangen mit Prat",
	["AllOff_name"] = "Alle Modules Aus",
	["AllOff_desc"] = "Schaltet alles aus so das du ausw\195\164hlen kannst was du brauchst.",
	} end)

-- get prat module categories
local cat = Prat.Categories

-- create Prat module
Prat_Presets = Prat:NewModule(PRAT_MODULE)
Prat_Presets.revision = tonumber(string.sub("$Revision: 28458 $", 12, -3))

-- define key module values
Prat_Presets.moduleName	    = L["Presets"] 	
Prat_Presets.consoleName	= string.lower(Prat_Presets.moduleName)
Prat_Presets.guiName		= Prat_Presets.moduleName

-- categories the module is related to, eg "{ cat.TEXT, cat.INFO }"
-- list here: http://groups-beta.google.com/group/wow-prat/web/prat-categories
-- !!
Prat_Presets.Categories	= { cat.FORMATTING, cat.BEHAVIOUR }

-- init moduleOoptions (populated by the other various options tables below)
Prat_Presets.moduleOptions = {}


local function PresetOpt(t, n)
    t[string.lower(n)] = {    
        name=L[n.."_name"],
        desc = L[n.."_desc"],
        type="execute",
        func=n 
        }
end
                

-- default values for any settings that need them
Prat_Presets.defaultDB = {
	on	= false,
	}


--[[------------------------------------------------
    Module Event Functions
------------------------------------------------]]--

function Prat_Presets:GetModuleOptions()
    self.moduleOptions = {
        type = "group",
        name = L["Presets"],
        desc = L["Preset Prat configurations to help get you started"],
        args = {
        }
    }
    
    local t = self.moduleOptions.args
    
    PresetOpt(t, "AllOff")
    
    return self.moduleOptions 
end    

--[[------------------------------------------------
    Core Functions
------------------------------------------------]]--
function Prat_Presets:AllOff()
	for n,m in Prat:IterateModules() do
		m.db.profile.on = false
		Prat:ToggleModuleActive(m, false)
	end
end

-- things do stuff here
